package com.pointrlabs.sample.utils

import android.app.Activity
import android.content.IntentSender
import com.google.android.gms.common.api.ResolvableApiException
import com.google.android.gms.location.LocationRequest
import com.google.android.gms.location.LocationServices
import com.google.android.gms.location.LocationSettingsRequest
import com.google.android.gms.location.Priority
import com.pointrlabs.core.nativecore.wrappers.Plog

fun Activity.handleLocationRequest(callBack : (ResolvableApiException?) -> Unit) {
    val locationRequest =
        LocationRequest.Builder(100000)
            .setPriority(Priority.PRIORITY_HIGH_ACCURACY)
            .build()

    val builder = LocationSettingsRequest.Builder()
        .addLocationRequest(locationRequest)

    LocationServices
        .getSettingsClient(this)
        .checkLocationSettings(builder.build())
        .addOnSuccessListener(this) { callBack(null) }
        .addOnFailureListener(this) { ex ->
            if (ex !is ResolvableApiException) return@addOnFailureListener
            try {
                callBack(ex)
            } catch (sendEx: IntentSender.SendIntentException) {
                Plog.w(sendEx.localizedMessage)
            }
        }
}